Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1818)

Unified Diff: content/public/browser/content_browser_client.h

Issue 2322673005: Fix process transfers for blob urls of sites requiring dedicated processes. (Closed)
Patch Set: Fix documentation. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/content_browser_client.h
diff --git a/content/public/browser/content_browser_client.h b/content/public/browser/content_browser_client.h
index d22a4866c6164a40879e6ae05e492906391c19b3..6da43c333166b7691eb7337088db5b0da45b070d 100644
--- a/content/public/browser/content_browser_client.h
+++ b/content/public/browser/content_browser_client.h
@@ -191,17 +191,17 @@ class CONTENT_EXPORT ContentBrowserClient {
virtual bool ShouldUseProcessPerSite(BrowserContext* browser_context,
const GURL& effective_url);
// Returns true if site isolation should be enabled for |effective_url|. This
// call allows the embedder to supplement the site isolation policy enforced
// by the content layer.
//
// Will only be called if both of the following happen:
// 1. The embedder asked to be consulted, by returning true from
// ContentClient::IsSupplementarySiteIsolationModeEnabled().
// 2. The content layer didn't decide to isolate |effective_url| according
// to its internal policy (e.g. because of --site-per-process).
virtual bool DoesSiteRequireDedicatedProcess(BrowserContext* browser_context,
- const GURL& effective_url);
+ const GURL& effective_site_url);
Charlie Reis 2016/09/09 21:18:24 Can you also update the parameter name in the foll
ncarter (slow) 2016/09/09 21:56:32 Done.
// Returns true unless the effective URL is part of a site that cannot live in
@@ -191,17 +191,17 @@ class CONTENT_EXPORT ContentBrowserClient {
virtual bool ShouldUseProcessPerSite(BrowserContext* browser_context,
const GURL& effective_url);
- // Returns true if site isolation should be enabled for |effective_url|. This
- // call allows the embedder to supplement the site isolation policy enforced
- // by the content layer.
+ // Returns true if site isolation should be enabled for |effective_site_url|.
+ // This call allows the embedder to supplement the site isolation policy
+ // enforced by the content layer.
//
// Will only be called if both of the following happen:
@@ -191,17 +191,17 @@ class CONTENT_EXPORT ContentBrowserClient {
// 1. The embedder asked to be consulted, by returning true from
// ContentClient::IsSupplementarySiteIsolationModeEnabled().
- // 2. The content layer didn't decide to isolate |effective_url| according
- // to its internal policy (e.g. because of --site-per-process).
+ // 2. The content layer didn't decide to isolate |effective_site_url|
+ // according to its internal policy (e.g. because of --site-per-process).
virtual bool DoesSiteRequireDedicatedProcess(BrowserContext* browser_context,
// a process restricted to just that site. This is only called if site

Powered by Google App Engine
This is Rietveld 408576698